@@ -397,6 +397,8 @@ sub _search_features_locally {
     my %seenit;
 
     for my $dbid (@dbids) {
+	my $opts = $self->source->search_options($dbid);
+	next if $opts =~ /none/i;
 	warn "searching in ",$dbid if DEBUG;
 	my $db = $self->source->open_database($dbid);
 	next if $seenit{$db}++;
@@ -404,11 +406,11 @@ sub _search_features_locally {
 	    { source     => $self->source,
 	      state      => $self->state,
 	      db         => $db,
-	      searchopts => $self->source->search_options($dbid),
+	      searchopts => $opts,
 	    }
 	    ); 
  	my $features = $region->search_features($args);
-	warn $features ? "got @$features" : "got no features" if DEBUG;
+	warn $features && @$features ? "[$$] got @$features" : "[$$] got no features" if DEBUG;
 	next unless $features && @$features;
 	$features = $self->filter_features($dbid,$features);
 	$self->add_dbid_to_features($dbid,$features);
